xsdata.codegen.handlers.attribute\_type module
==============================================

.. automodule:: xsdata.codegen.handlers.attribute_type
   :members:
   :undoc-members:
   :show-inheritance:
